/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea;

import com.googlecode.sca4idea.providers.ProviderReferenceRegistrarFactory;
import com.googlecode.sca4idea.providers.ProviderReferenceRegistrarFactoryImpl;
import com.googlecode.sca4idea.providers.SCAProviderRegistry;
import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.project.Project;
import com.intellij.psi.impl.source.resolve.reference.ReferenceProvidersRegistry;
import org.jetbrains.annotations.NotNull;

/**
 * Project component for installing project-level functionality for the plugin.
 */
public class SCAProjectComponent implements ProjectComponent {
    private final Project project;
    private final ProviderReferenceRegistrarFactory registrarFactory;

    public SCAProjectComponent(Project project) {
        this.project = project;
        this.registrarFactory = new ProviderReferenceRegistrarFactoryImpl(
                ReferenceProvidersRegistry.getInstance(project));
    }

    public void initComponent() {
    }

    public void disposeComponent() {
    }

    @NotNull
    public String getComponentName() {
        return "SCAProjectComponent";
    }

    public void projectOpened() {
        // Initialise the reference providers in the components
        SCAProviderRegistry.getInstance().registerReferences(registrarFactory);
    }

    public void projectClosed() {
        // called when project is being closed
    }
}
