/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea.facet;

import com.intellij.facet.ui.FacetEditorTab;
import com.intellij.openapi.options.ConfigurationException;
import org.jetbrains.annotations.Nls;

import javax.swing.*;

/**
 * Tab for configuring a Facet.
 */
public class FacetConfigurationEditor extends FacetEditorTab {
    private FacetEditorPanel editorPanel;

    public FacetConfigurationEditor(SCAFacetConfiguration configuration) {
        editorPanel = new FacetEditorPanel(configuration);
    }

    @Nls
    public String getDisplayName() {
        return editorPanel.getDisplayName();
    }

    public JComponent createComponent() {
        return editorPanel.getMainPanel();
    }

    public boolean isModified() {
        return editorPanel.isModified();
    }

    public void apply() throws ConfigurationException {
        editorPanel.apply();
    }

    public void reset() {
        editorPanel.reset();
    }

    public void disposeUIResources() {
        editorPanel.disposeUIResources();
    }
}
