/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea.facet;

import com.intellij.facet.Facet;
import com.intellij.facet.FacetType;
import com.intellij.facet.FacetManager;
import com.intellij.openapi.module.Module;
import com.intellij.openapi.module.ModuleUtil;
import com.intellij.psi.PsiElement;
import org.jetbrains.annotations.NotNull;
import com.googlecode.sca4idea.providers.SCAProvider;

/**
 * Facet that can be applied to Java modules for support Service Component Architecture features.
 */
public class SCAFacet extends Facet<SCAFacetConfiguration> {
    public SCAFacet(@NotNull FacetType facetType, @NotNull Module module, String name,
                    @NotNull SCAFacetConfiguration config, Facet facet) {
        super(facetType, module, name, config, facet);
    }

    /**
     * Retrieves the SCAProvider for the given element.
     * @param psiElement the element to determine the provider for.
     * @return the provider.
     */
    public static SCAProvider getProviderForElement(PsiElement psiElement) {
        Module elementModule = ModuleUtil.findModuleForPsiElement(psiElement);
        if (elementModule == null) return null;  

        SCAFacet facet = FacetManager.getInstance(elementModule).getFacetByType(SCAFacetType.ID);
        if (facet == null) return null;

        return facet.getConfiguration().getSelectedProvider();
    }
}
