/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea.facet;

import com.intellij.facet.impl.ui.FacetTypeFrameworkSupportProvider;
import com.intellij.facet.FacetManager;
import com.intellij.facet.ModifiableFacetModel;
import com.intellij.ide.util.newProjectWizard.FrameworkSupportProvider;
import com.intellij.openapi.module.Module;
import com.intellij.openapi.roots.ModifiableRootModel;
import com.intellij.openapi.roots.libraries.Library;
import com.googlecode.sca4idea.SCABundle;
import org.jetbrains.annotations.Nullable;

/**
 * Framework support provider for applying the SCA Facet.
 */
public class SCAFacetFrameworkSupportProvider extends FrameworkSupportProvider {
    public SCAFacetFrameworkSupportProvider() {
        super(FacetTypeFrameworkSupportProvider.getProviderId(SCAFacetType.ID),
                SCABundle.message("framework.title.service.component.architecture"));
    }

    public void addSupport(final Module module, final ModifiableRootModel rootModel, final @Nullable Library library) {
      FacetManager facetManager = FacetManager.getInstance(module);
      ModifiableFacetModel facetModel = facetManager.createModifiableModel();
      SCAFacet facet = facetManager.createFacet(SCAFacetType.INSTANCE, SCAFacetType.INSTANCE.getDefaultFacetName(), null);
      facetModel.addFacet(facet);
      facetModel.commit();
    }
}
