/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea.providers;

import com.intellij.openapi.project.Project;
import com.intellij.patterns.ElementPattern;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiReferenceProvider;
import org.jetbrains.annotations.NotNull;

/**
 * Registrar facade interface for allowing providers to register reference providers specific to their implementation.
 */
public interface ProviderReferenceRegistrar {
    /**
     * Retrieves the project the registrar is associated with.
     * @return the associated project.
     */
    Project getProject();

    /**
     * Registers a reference provider that will be applied when the given pattern is matched.
     * @param pattern the pattern to match.
     * @param referenceProvider the reference provider to apply when the pattern is matched.
     */
    void registerReferenceProvider(@NotNull ElementPattern<? extends PsiElement> pattern,
                                   @NotNull PsiReferenceProvider referenceProvider);
}
