/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea.providers;

import com.intellij.psi.PsiReferenceRegistrar;

import java.util.HashMap;
import java.util.Map;

/**
 * Implementation of the provider reference registrar factory.
 */
public class ProviderReferenceRegistrarFactoryImpl implements ProviderReferenceRegistrarFactory {
    private final PsiReferenceRegistrar registrar;
    private final Map<String, ProviderReferenceRegistrar> registrars = new HashMap<String, ProviderReferenceRegistrar>();

    public ProviderReferenceRegistrarFactoryImpl(PsiReferenceRegistrar registrar) {
        this.registrar = registrar;
    }

    public ProviderReferenceRegistrar getRegistrar(SCAProvider provider) {
        if (!registrars.containsKey(provider.getId())) {
            registrars.put(provider.getId(), new ProviderReferenceRegistrarImpl(provider.getId(), registrar));
        }

        return registrars.get(provider.getId());
    }
}
