/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea.providers;

import java.util.ArrayList;
import java.util.List;

/**
 * Implementation of the SCAProviderRegistry.
 */
public class SCAProviderRegistryImpl extends SCAProviderRegistry {
    private final List<SCAProvider> providers = new ArrayList<SCAProvider>();

    public SCAProvider[] getAllProviders() {
        return providers.toArray(new SCAProvider[providers.size()]);
    }

    public SCAProvider getProviderById(String id) {
        for (SCAProvider provider : providers) {
            if (provider.getId().equals(id)) {
                return provider;
            }
        }

        return null;
    }

    public void registerStaticProvider(SCAProvider provider) {
        providers.add(provider);
    }

    @Override
    public void registerReferences(ProviderReferenceRegistrarFactory registrar) {
        for (SCAProvider provider : providers) {
            provider.registerReferences(registrar.getRegistrar(provider));
        }
    }
}
