/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea.references;

import com.googlecode.sca4idea.psi.SCAComponentTagPsiElement;
import com.googlecode.sca4idea.util.ComponentResolver;
import com.googlecode.sca4idea.providers.SCAProvider;
import com.googlecode.sca4idea.facet.SCAFacet;
import org.jetbrains.annotations.NotNull;
import com.intellij.psi.xml.XmlAttributeValue;
import com.intellij.psi.xml.XmlAttribute;
import com.intellij.psi.xml.XmlTag;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiReference;

/**
 * Abstract base used by reference providers that denote the "name" attribute on a providing element (eg providing
 * reference wire or property).
 */
public abstract class AbstractProvidingReferenceProvider extends AbstractReferenceProvider {
    protected abstract Object[] getVariantsForComponent(SCAComponentTagPsiElement component);
    protected abstract PsiElement resolveForComponent(SCAComponentTagPsiElement component, String text);

    @NotNull
    public PsiReference[] getReferencesByString(String s, PsiElement psiElement, int i) {
        final SCAProvider provider = SCAFacet.getProviderForElement(psiElement);

        return new PsiReference[] {
              new XmlAttributeValuePsiReference((XmlAttributeValue)psiElement, SCAReferencesUtil.getAllRange(s)) {

                    public boolean isSoft() {
                        return AbstractProvidingReferenceProvider.this.isSoft();
                    }

                    public Object[] getVariants() {
                        SCAComponentTagPsiElement currentComponent = getComponentForCurrentAttr(provider, (XmlAttributeValue) getElement());
                        return getVariantsForComponent(currentComponent);
                    }

                    public PsiElement resolve() {
                        SCAComponentTagPsiElement currentComponent = getComponentForCurrentAttr(provider, (XmlAttributeValue) getElement());
                        return resolveForComponent(currentComponent, getCanonicalText());
                    }
              }
        };
    }

    protected SCAComponentTagPsiElement getComponentForCurrentAttr(SCAProvider provider, XmlAttributeValue attrVal) {
        XmlAttribute attr = (XmlAttribute) attrVal.getParent();
        XmlTag referenceTag = attr.getParent();
        XmlTag componentTag = referenceTag.getParentTag();

        return ComponentResolver.getSCAComponentInstance(provider, componentTag);
    }
}
