/*
 * Copyright (C) 2008
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.sca4idea.references;

import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiReference;
import com.intellij.psi.xml.XmlAttributeValue;
import com.googlecode.sca4idea.util.SCDLResolver;
import com.googlecode.sca4idea.references.XmlAttributeValuePsiReference;
import com.googlecode.sca4idea.references.SCAReferencesUtil;
import org.jetbrains.annotations.NotNull;

/**
 * ReferenceProvider for working with scdlLocation attributes in implementation.composite tags.
 *
 * @author paul.jones
 */
public class SCDLLocationReferenceProvider extends AbstractReferenceProvider {

    @NotNull
    public PsiReference[] getReferencesByString(String s, PsiElement psiElement, int i) {
        return new PsiReference[] {
          new XmlAttributeValuePsiReference((XmlAttributeValue)psiElement, SCAReferencesUtil.getAllRange(s)) {

                public boolean isSoft() {
                    return SCDLLocationReferenceProvider.this.isSoft();
                }

                public Object[] getVariants() {
                    return new Object[0];
                }

                public PsiElement resolve() {
                    return SCDLResolver.loadScdlLocation(getElement(), getCanonicalText());
                }
          }
        };
    }
}